@@ -1,18 +1,19 @@
-from onlineafspraken.api.client import OnlineAfsprakenAPI
+from onlineafspraken.api.client import OnlineAfsprakenAPI, client
 from onlineafspraken.schema.appointment import (
     CancelAppointmentResponse,
     ConfirmAppointmentResponse,
     GetAppointmentsResponse,
     GetAppointmentResponse,
-    SetAppointmentResponse, SetAppointmentSchema,
+    SetAppointmentResponse,
+    SetAppointmentSchema,
 )
 
 
 def cancel_appointment(
     appointment_id, mode=None, remarks=None, confirmation=None, dry_run=None
 ) -> CancelAppointmentResponse:
-    api = OnlineAfsprakenAPI()
-    resp = api.get(
+
+    resp = client.get(
         "cancelAppointment",
         id=appointment_id,
         mode=mode,
@@ -21,18 +22,18 @@ def cancel_appointment(
         dryRun=dry_run,
     )
 
-    return CancelAppointmentResponse.parse_obj(resp["Response"])
+    return CancelAppointmentResponse.parse_obj(resp)
 
 
 def confirm_appointment(
     appointment_id, confirmation_code
 ) -> ConfirmAppointmentResponse:
-    api = OnlineAfsprakenAPI()
-    resp = api.get(
+
+    resp = client.get(
         "confirmAppointment", id=appointment_id, confirmationCode=confirmation_code
     )
 
-    return ConfirmAppointmentResponse.parse_obj(resp["Response"])
+    return ConfirmAppointmentResponse.parse_obj(resp)
 
 
 def get_appointments(
@@ -46,8 +47,8 @@ def get_appointments(
     limit=None,
     offset=None,
 ) -> GetAppointmentsResponse:
-    api = OnlineAfsprakenAPI()
-    resp = api.get(
+
+    resp = client.get(
         "getAppointments",
         agendaId=agenda_id,
         startDate=start_date,
@@ -60,19 +61,20 @@ def get_appointments(
         offset=offset,
     )
 
-    return GetAppointmentsResponse.parse_obj(resp["Response"])
+    return GetAppointmentsResponse.parse_obj(resp)
 
 
 def get_appointment(appointment_id) -> GetAppointmentResponse:
-    api = OnlineAfsprakenAPI()
-    resp = api.get("getAppointment", id=appointment_id)
 
-    return GetAppointmentResponse.parse_obj(resp["Response"])
+    resp = client.get("getAppointment", id=appointment_id)
+
+    return GetAppointmentResponse.parse_obj(resp)
 
 
 def remove_appointment(appointment_id) -> None:
-    api = OnlineAfsprakenAPI()
-    response = api.get("removeAppointment", id=appointment_id)
+
+    response = client.get("removeAppointment", id=appointment_id)
+
     return response
 
 
@@ -88,8 +90,8 @@ def set_appointment(
     description=None,
     booking_mode=None,
 ) -> SetAppointmentSchema:
-    api = OnlineAfsprakenAPI()
-    resp = api.get(
+
+    resp = client.get(
         "setAppointment",
         Id=appointment_id,
         AgendaId=agenda_id,
@@ -103,6 +105,6 @@ def set_appointment(
         BookingMode=booking_mode,
     )
 
-    response = SetAppointmentResponse.parse_obj(resp["Response"])
+    response = SetAppointmentResponse.parse_obj(resp)
 
     return response.objects["Appointment"]
